==> dde-shell_1.99.7.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>無線LAN on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>無線LAN off</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock off</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>数字キーボード on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>数字キーボード off</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>タッチパッド on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>タッチパッド off</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>タッチパッド トグル</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Fn トグル</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>機内モード on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>機内モードoff</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>ミュート on</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>ミュート off</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>バランス</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>省電力</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>高パフォーマンス</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>ウィンドウ エフェクトが有効化されました</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>ウィンドウ エフェクト が無効化されました</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>ウィンドウ エフェクトを有効化できませんでした</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.32.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>無線LAN ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>無線LAN OFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock OFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>テンキー ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>テンキー OFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>タッチパッド ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>タッチパッド OFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>タッチパッド トグル</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Fn トグル</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>機内モード ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>機内モードOFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>ミュート ON</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>ミュート OFF</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>バランス</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>省電力</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>高パフォーマンス</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>ウィンドウ エフェクトが有効化されました</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>ウィンドウ エフェクト が無効化されました</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>ウィンドウ エフェクトを有効化できませんでした</translation>
    </message>
</context>
</TS>
